@@ -12,11 +12,17 @@ class MainLoopMixin(DeviceCore):
     # _logger = logging.getLogger(__name__)
 
     def run(self):
-        self.loop = asyncio.get_event_loop()
-        self.task = self.loop.create_task(self.main())
-        self.loop.run_until_complete(self.task)
-        if self.log:
-            self.log.info("shutdown")
+        try:
+            self.loop = asyncio.get_event_loop()
+            self.task = self.loop.create_task(self.main())
+            self.loop.run_until_complete(self.task)
+            if self.log:
+                self.log.info("shutdown")
+        except KeyboardInterrupt:
+            if self.log:
+                self.log.info("KeyboardInterrupt")
+            self.task.cancel()
+            self.loop.run_until_complete(self.task)
 
     async def stop(self):
         try:
